@@ -182,10 +182,24 @@ def get_image_file_path(name: str, default: str = "not_found.png") -> str:
 ICON_CACHE = {}
 
 
+def get_std_icon(name: str) -> QG.QIcon | None:
+    """Get standard icon by name"""
+    # Importing Qt objects here because this module should not depend on them
+    # pylint: disable=import-outside-toplevel
+
+    # Try to get standard icon first
+    from guidata.qthelpers import get_std_icon
+
+    try:
+        return get_std_icon(name)
+    except AttributeError:
+        return None
+
+
 def get_icon(name: str, default: str = "not_found.png") -> QG.QIcon:
     """
     Construct a QIcon from the file with specified name
-    name, default: filenames with extensions
+    name, default: filenames with extensions or standard Qt icon names
 
     Args:
         name (str): name of the icon
@@ -197,11 +211,25 @@ def get_icon(name: str, default: str = "not_found.png") -> QG.QIcon:
     try:
         return ICON_CACHE[name]
     except KeyError:
-        # Importing Qt here because this module should be independent from it
-        from qtpy import QtGui as QG  # pylint: disable=import-outside-toplevel
+        std_icon = get_std_icon(name)
+        if std_icon is not None:
+            return std_icon
 
-        icon = QG.QIcon(get_image_file_path(name, default))
-        ICON_CACHE[name] = icon
+        std_default_icon = get_std_icon(default)
+
+        # Importing Qt objects here because this module should not depend on them
+        # pylint: disable=import-outside-toplevel
+
+        # Retrieve icon from file (original implementation)
+        from qtpy import QtGui as QG
+
+        try:
+            icon = QG.QIcon(get_image_file_path(name, default))
+            ICON_CACHE[name] = icon
+        except RuntimeError:  # default is a standard icon name
+            if std_default_icon is not None:
+                return std_default_icon
+            raise
         return icon
 
 
@@ -271,10 +299,10 @@ def font_is_installed(font: str) -> list[str]:
         list[str]: list of installed fonts
     """
     # Importing Qt here because this module should be independent from it
-    from qtpy import QT5
+    from qtpy import PYQT5
     from qtpy import QtGui as QG  # pylint: disable=import-outside-toplevel
 
-    if QT5:
+    if PYQT5:
         fontfamilies = QG.QFontDatabase().families()
     else:
         # Qt6
@@ -288,14 +316,17 @@ MONOSPACE = [
     "Cascadia Code",
     "Cascadia Mono",
     "Consolas",
+    "Lucida Console",
+    "Lucida Sans Typewriter",
     "Monospace",
     "Menlo",
     "Courier New",
+    "Courier",
     "Bitstream Vera Sans Mono",
     "Andale Mono",
     "Liberation Mono",
     "Monaco",
-    "Courier",
+    "Fixedsys",
     "monospace",
     "Fixed",
     "Terminal",
@@ -317,8 +348,14 @@ def get_family(families: str | list[str]) -> str:
         if font_is_installed(family):
             return family
     else:
-        warnings.warn("None of the following fonts is installed: %r" % families)
-        return ""
+        # On Windows, in offscreen/headless mode, Qt may not detect fonts properly
+        # Don't warn in this case, just return the first family as a fallback
+        is_windows_offscreen = (
+            sys.platform == "win32" and os.environ.get("QT_QPA_PLATFORM") == "offscreen"
+        )
+        if not is_windows_offscreen:
+            warnings.warn("None of the following fonts is installed: %r" % families)
+        return families[0] if families else ""
 
 
 def get_font(conf: UserConfig, section: str, option: str = "") -> QG.QFont:
