@@ -10,6 +10,8 @@ from .conv import (
     create_dataset_from_func,
     restore_dataset,
     update_dataset,
+    dataset_to_json,
+    json_to_dataset,
 )
 from .dataitems import (
     BoolItem,
@@ -28,6 +30,7 @@ from .dataitems import (
     FontFamilyItem,
     ImageChoiceItem,
     IntItem,
+    LabeledEnum,
     MultipleChoiceItem,
     StringItem,
     TextItem,
@@ -35,8 +38,12 @@ from .dataitems import (
 from .datatypes import (
     ActivableDataSet,
     AnyDataSet,
+    assert_datasets_equal,
     BeginGroup,
     BeginTabGroup,
+    ComputedProp,
+    DataItemValidationWarning,
+    DataItemValidationError,
     DataItem,
     DataItemProxy,
     DataItemVariable,
@@ -47,6 +54,7 @@ from .datatypes import (
     EndTabGroup,
     FormatProp,
     FuncProp,
+    FuncPropMulti,
     GetAttrProp,
     GroupItem,
     ItemProperty,
@@ -54,6 +62,7 @@ from .datatypes import (
     NotProp,
     Obj,
     ObjectItem,
+    SeparatorItem,
     TabGroupItem,
     ValueProp,
 )
