@@ -34,6 +34,9 @@ Grouping items
 .. autoclass:: guidata.dataset.EndTabGroup
     :members:
 
+.. autoclass:: guidata.dataset.SeparatorItem
+    :members:
+
 Handling item properties
 ^^^^^^^^^^^^^^^^^^^^^^^^
 
@@ -65,11 +68,15 @@ from __future__ import annotations
 
 import re
 import sys
+import warnings
 from abc import ABC, abstractmethod
 from collections.abc import Callable
 from copy import deepcopy
 from typing import TYPE_CHECKING, Any, TypeVar
 
+import numpy as np
+
+from guidata.config import ValidationMode, get_validation_mode
 from guidata.io import INIReader, INIWriter
 from guidata.userconfig import UserConfig
 
@@ -79,11 +86,42 @@ if TYPE_CHECKING:
     from qtpy.QtCore import QSize
     from qtpy.QtWidgets import QDialog, QWidget
 
-    from guidata.dataset.qtwidgets import DataSetEditDialog
     from guidata.io import HDF5Reader, HDF5Writer, JSONReader, JSONWriter
 
 
+class DataItemValidationWarning(UserWarning):
+    """Warning raised when a DataItem value is invalid
+    and validation mode is 'ENABLED'"""
+
+    pass
+
+
+class DataItemValidationError(ValueError):
+    """Error raised when a DataItem value is invalid during validation.
+    Provides more context about where the error occurred.
+
+    Args:
+        instance: the DataSet instance where the error occurred
+        item: the DataItem that caused the error
+        msg: error message
+        operation: operation that failed, if applicable
+    """
+
+    def __init__(
+        self, instance: DataSet, item: DataItem, msg: str, operation: str | None = None
+    ) -> None:
+        self.item = item
+        self.operation = operation
+        if operation:
+            full_msg = f"{operation} failed for {item}: {msg}"
+        else:
+            full_msg = f"Checking {instance.__class__.__name__}.{item}: {msg}"
+        super().__init__(full_msg)
+
+
 class NoDefault:
+    """Special value used to indicate that no default value is set for a DataItem"""
+
     pass
 
 
@@ -128,7 +166,7 @@ class FormatProp(ItemProperty):
     """
 
     def __init__(self, fmt: str, ignore_error: bool | None = True) -> None:
-        """fmt is a format string
+        """`fmt` is a format string
         it can contain a single anonymous substition or
         several named substitions.
         """
@@ -288,6 +326,67 @@ class FuncPropMulti(ItemProperty):
             prop.set(instance, item, self.inverse_function(value))
 
 
+class ComputedProp(ItemProperty):
+    """A computed property that calls a method of the dataset to calculate values
+
+    Args:
+        method_or_name: name of the method to call on the dataset instance,
+         or the function object itself
+    """
+
+    def __init__(self, method_or_name: str | callable) -> None:
+        if callable(method_or_name):
+            self.method = method_or_name
+            self.method_name = getattr(method_or_name, "__name__", str(method_or_name))
+        else:
+            self.method = None
+            self.method_name = method_or_name
+
+    # pylint: disable=unused-argument
+    def __call__(self, instance: DataSet, item: DataItem, value: Any) -> Any:
+        """Compute the value by calling the specified method on the dataset instance
+
+        Args:
+            instance (DataSet): dataset instance
+            item (DataItem): the data item
+            value (Any): current value (ignored for computed items)
+
+        Returns:
+            Any: computed value
+        """
+        if self.method is not None:
+            # Function object was provided directly
+            return self.method(instance)
+        else:
+            # Method name was provided, get it from the instance
+            method = getattr(instance, self.method_name, None)
+            if method is None:
+                raise AttributeError(
+                    f"Dataset {instance.__class__.__name__} has no method "
+                    f"'{self.method_name}'"
+                )
+            if not callable(method):
+                raise TypeError(
+                    f"Attribute '{self.method_name}' of {instance.__class__.__name__} "
+                    "is not callable"
+                )
+            return method()
+
+    # pylint: disable=unused-argument
+    def set(self, instance: DataSet, item: DataItem, value: Any) -> None:
+        """Computed properties cannot be set directly - they are read-only
+
+        Args:
+            instance (DataSet): instance of the DataSet
+            item (DataItem): item to set the value of
+            value (Any): value to set
+
+        Raises:
+            ValueError: Always, since computed items are read-only
+        """
+        raise ValueError(f"Computed item '{item.get_name()}' is read-only")
+
+
 class DataItem(ABC):
     """DataSet data item
 
@@ -296,6 +395,8 @@ class DataItem(ABC):
         default (Any): default value
         help (str): text displayed on data item's tooltip
         check (bool): check value (default: True)
+        allow_none (bool): if True, None values are allowed regardless of the
+            expected type (default: False)
     """
 
     type = type
@@ -307,6 +408,7 @@ class DataItem(ABC):
         default: Any | None = None,
         help: str | None = "",
         check: bool | None = True,
+        allow_none: bool = False,
     ) -> None:
         self._order = DataItem.count
         DataItem.count += 1
@@ -317,7 +419,7 @@ class DataItem(ABC):
             Any, Any
         ] = {}  # a dict realm->dict containing realm-specific properties
         self.set_prop("display", col=0, colspan=None, row=None, label=label)
-        self.set_prop("data", check_value=check)
+        self.set_prop("data", check_value=check, allow_none=allow_none)
 
     def get_prop(self, realm: str, name: str, default: Any = NoDefault) -> Any:
         """Get one property of this item
@@ -330,12 +432,15 @@ class DataItem(ABC):
         Returns:
             Any: property value
         """
-        prop = self._props.get(realm)
-        if not prop:
-            prop = {}
+        realm_props = self._props.get(realm)
+        if realm_props is None:
+            if default is NoDefault:
+                raise KeyError(name)
+            return default
+
         if default is NoDefault:
-            return prop[name]
-        return prop.get(name, default)
+            return realm_props[name]  # Let KeyError propagate
+        return realm_props.get(name, default)
 
     def get_prop_value(
         self, realm: str, instance: DataSet, name: str, default: Any = NoDefault
@@ -390,6 +495,22 @@ class DataItem(ABC):
         self.set_prop("display", col=col, colspan=colspan, row=row)
         return self
 
+    def set_computed(self, method_or_name: str | callable) -> DataItem:
+        """Set data item as computed using the specified method
+
+        Args:
+            method_or_name: name of the method to call on the dataset instance to
+             compute the value, or the function object itself
+
+        Returns:
+            DataItem: self
+        """
+        computed_prop = ComputedProp(method_or_name)
+        self.set_prop("data", computed=computed_prop)
+        # Also make it readonly in the display
+        self.set_prop("display", readonly=True)
+        return self
+
     def __str__(self) -> str:
         return f"{self._name} : {self.__class__.__name__}"
 
@@ -459,7 +580,7 @@ class DataItem(ABC):
             if value is not None:
                 text = self.format_string(instance, value, fmt, func)
             else:
-                text = ""
+                text = "-"
             return text
 
     def get_name(self) -> str:
@@ -510,7 +631,18 @@ class DataItem(ABC):
         Args:
             instance (DataSet): instance of the DataSet
         """
-        self.__set__(instance, deepcopy(self._default))
+        try:
+            value = deepcopy(self._default)
+            self._set_value_with_validation(instance, value, force_allow_none=True)
+        except ValueError as exc:
+            # Convert generic ValueError to a more specific DataItemValidationError
+            # to provide clearer context when setting default values fails
+            raise DataItemValidationError(
+                instance,
+                self,
+                str(exc.__cause__ or exc),
+                operation=f"Setting default value ({instance.__class__.__name__})",
+            ) from exc
 
     def accept(self, visitor: object) -> None:
         """This is the visitor pattern's accept function.
@@ -529,12 +661,73 @@ class DataItem(ABC):
         func = getattr(visitor, funcname)
         func(self)
 
-    def __set__(self, instance: Any, value: Any):
-        setattr(instance, "_%s" % (self._name), value)
+    def __set__(self, instance: Any, value: Any) -> None:
+        """Set data item's value
+
+        Args:
+            instance (Any): instance of the DataSet
+            value (Any): value to set
+        """
+        # Check if this item is computed (read-only)
+        computed_prop = self.get_prop("data", "computed", None)
+        if isinstance(computed_prop, ComputedProp):
+            raise ValueError(f"Computed item '{self.get_name()}' is read-only")
+
+        self._set_value_with_validation(instance, value, force_allow_none=False)
+
+    def _set_value_with_validation(
+        self, instance: Any, value: Any, force_allow_none: bool = False
+    ) -> None:
+        """Internal method to set data item's value with validation
+
+        Args:
+            instance (Any): instance of the DataSet
+            value (Any): value to set
+            force_allow_none (bool): if True, allow None values even when
+             allow_none is False (used for default values)
+        """
+        vmode = get_validation_mode()
+
+        # Early exit if validation is disabled
+        if vmode == ValidationMode.DISABLED:
+            setattr(instance, f"_{self._name}", value)
+            return
+
+        # Check if validation should be skipped for None values
+        if value is None:
+            if force_allow_none or self.get_prop("data", "allow_none", False):
+                setattr(instance, f"_{self._name}", value)
+                return
+
+        # Perform validation
+        try:
+            self.check_value(value, raise_exception=True)
+        except NotImplementedError:
+            # Checking is not implemented for this item
+            pass
+        except Exception as exc:
+            if vmode == ValidationMode.ENABLED:
+                # Show a warning in replacement of the exception
+                msg = f"Checking {instance.__class__.__name__}.{str(self)}: {exc}"
+                warnings.warn(msg, DataItemValidationWarning)
+            elif vmode == ValidationMode.STRICT:
+                # Raise an exception if strict validation is enabled
+                raise DataItemValidationError(instance, self, str(exc)) from exc
+            else:
+                raise ValueError(f"Unknown validation mode: {vmode}") from exc
+
+        setattr(instance, f"_{self._name}", value)
 
     def __get__(self, instance: Any, klass: type) -> Any | None:
         if instance is not None:
-            return getattr(instance, "_%s" % (self._name), self._default)
+            # Check if this item is computed
+            computed_prop = self.get_prop("data", "computed", None)
+            if isinstance(computed_prop, ComputedProp):
+                # For computed items, calculate the value using the computed property
+                return computed_prop(instance, self, None)
+            else:
+                # For regular items, return the stored value or default
+                return getattr(instance, "_%s" % (self._name), self._default)
         else:
             return self
 
@@ -549,7 +742,7 @@ class DataItem(ABC):
         """
         return self.__get__(instance, instance.__class__)
 
-    def check_item(self, instance: Any) -> Any:
+    def check_item(self, instance: Any) -> bool:
         """Check data item's current value (calling method check_value)
 
         Args:
@@ -561,11 +754,13 @@ class DataItem(ABC):
         value = getattr(instance, "_%s" % (self._name))
         return self.check_value(value)
 
-    def check_value(self, value: Any) -> bool:
+    def check_value(self, value: Any, raise_exception: bool = False) -> bool:
         """Check if `value` is valid for this data item
 
         Args:
             value (Any): value to check
+            raise_exception (bool): if True, raise an exception if the value is invalid.
+            Defaults to True.
 
         Returns:
             bool: value
@@ -719,6 +914,14 @@ class DataItemProxy:
     def __str__(self):
         return self.item._name + "_proxy: " + self.__class__.__name__
 
+    def get_name(self) -> str:
+        """DataItem method proxy
+
+        Returns:
+            str: name
+        """
+        return self.item.get_name()
+
     def get_help(self, instance: DataSet) -> str:
         """DataItem method proxy
 
@@ -791,7 +994,7 @@ class DataItemProxy:
         """
         return self.item.get_value(instance)
 
-    def check_item(self, instance: DataItem) -> Any:
+    def check_item(self, instance: DataItem) -> bool:
         """DataItem method proxy
 
         Args:
@@ -802,16 +1005,18 @@ class DataItemProxy:
         """
         return self.item.check_item(instance)
 
-    def check_value(self, value: Any) -> Any:
+    def check_value(self, value: Any, raise_exception: bool = False) -> bool:
         """DataItem method proxy
 
         Args:
             value (Any): value
+            raise_exception (bool): if True, raise an exception if the value is invalid.
+             Defaults to True.
 
         Returns:
             Any: value
         """
-        return self.item.check_value(value)
+        return self.item.check_value(value, raise_exception)
 
     def from_string(self, string_value: str) -> Any:
         """DataItem method proxy
@@ -979,7 +1184,7 @@ class DataItemVariable:
         """
         return self.item.set_from_string(self.instance, string_value)
 
-    def check_item(self) -> Any:
+    def check_item(self) -> bool:
         """Re-implement DataItem method
 
         Returns:
@@ -987,16 +1192,18 @@ class DataItemVariable:
         """
         return self.item.check_item(self.instance)
 
-    def check_value(self, value) -> Any:
+    def check_value(self, value: Any, raise_exception: bool = False) -> bool:
         """Re-implement DataItem method
 
         Args:
             value (Any): value
+            raise_exception (bool): if True, raise an exception if the value is invalid.
+             Defaults to True.
 
         Returns:
             Any: value
         """
-        return self.item.check_value(value)
+        return self.item.check_value(value, raise_exception)
 
     def from_string(self, string_value: str) -> Any:
         """Re-implement DataItem method
@@ -1018,6 +1225,68 @@ class DataItemVariable:
         return self.item.get_prop("display", "label")
 
 
+def collect_items_in_bases_order(
+    bases: tuple[type], seen: set | None = None
+) -> list[DataItem]:
+    """Collect items in bases order
+
+    Args:
+        bases: tuple of base classes
+        seen: set of already seen items to avoid duplicates
+
+    Returns:
+        List of data items
+    """
+    if seen is None:
+        seen = set()
+
+    # Collect all bases, respecting the order they appear in class definition
+    # For DerivedAB(DatasetA, DatasetB), we want DatasetA items first
+    all_bases = []
+    for base in bases:
+        # Get all bases of this base class in MRO order (excluding object)
+        base_mro = [cls for cls in base.__mro__ if cls is not object]
+        all_bases.extend(base_mro)
+
+    # Remove duplicates while preserving order (use dict as ordered set)
+    unique_bases = list(dict.fromkeys(all_bases))
+
+    # Build a mapping of overridden items (most specific class wins)
+    items_dict = {}  # name -> DataItem mapping
+    for base in reversed(unique_bases):  # Reverse MRO: most specific first
+        base_dict = getattr(base, "__dict__", {})
+        for name, obj in base_dict.items():
+            if isinstance(obj, DataItem):
+                items_dict[name] = obj  # Later (more specific) definitions override
+
+    # Now collect items following the inheritance chain order in bases
+    # Process each base and its ancestors in the order they appear
+    final_items = []
+    processed_bases = set()
+
+    for base in bases:  # Process in the order bases are listed in class definition
+        # Get MRO for this base, but exclude DataSet and object
+        base_chain = [
+            cls
+            for cls in base.__mro__
+            if cls is not object and issubclass(cls, DataSet)
+        ]
+
+        # Process from most ancestral to most derived within this chain
+        for cls in reversed(base_chain):
+            if cls in processed_bases:
+                continue  # Skip if already processed
+            processed_bases.add(cls)
+
+            cls_dict = getattr(cls, "__dict__", {})
+            for name, obj in cls_dict.items():
+                if isinstance(obj, DataItem) and name not in seen:
+                    final_items.append(items_dict[name])  # Use the overridden version
+                    seen.add(name)
+
+    return final_items
+
+
 class DataSetMeta(type):
     """
     DataSet metaclass
@@ -1026,24 +1295,21 @@ class DataSetMeta(type):
     created in the same order as these attributes were written
     """
 
-    def __new__(cls: type, name: str, bases: Any, dct: dict[str, Any]) -> type:
-        items = {}
-        for base in bases:
-            if getattr(base, "__metaclass__", None) is DataSetMeta:
-                for item in base._items:
-                    items[item._name] = item
-
+    def __new__(
+        cls: type, name: str, bases: Any, dct: dict[str, Any], **kwargs
+    ) -> type:
+        # Filter out DataSet configuration kwargs (handled by __init_subclass__)
+        # These include: title, comment, icon, readonly
+        items = {item._name: item for item in collect_items_in_bases_order(bases)}
         for attrname, value in list(dct.items()):
             if isinstance(value, DataItem):
                 value.set_name(attrname)
                 if attrname in items:
                     value._order = items[attrname]._order
                 items[attrname] = value
-        items_list = list(items.values())
-        items_list.sort(key=lambda x: x._order)
-
-        dct["_items"] = items_list
-        return type.__new__(cls, name, bases, dct)
+        dct["_items"] = list(items.values())
+        # Pass kwargs through to type.__new__ (which will trigger __init_subclass__)
+        return super().__new__(cls, name, bases, dct, **kwargs)
 
 
 Meta_Py3Compat = DataSetMeta("Meta_Py3Compat", (object,), {})
@@ -1052,6 +1318,44 @@ Meta_Py3Compat = DataSetMeta("Meta_Py3Compat", (object,), {})
 AnyDataSet = TypeVar("AnyDataSet", bound="DataSet")
 
 
+def assert_datasets_equal(ds1: DataSet, ds2: DataSet, msg: str | None = None) -> None:
+    """Assert that two DataSet objects are equal. Exception message shows details on
+    which attributes are different, if any.
+
+    Args:
+        ds1: The first DataSet to compare.
+        ds2: The second DataSet to compare.
+        msg: Optional message to include in the assertion error.
+
+    Raises:
+        AssertionError: If the DataSet objects are not equal.
+    """
+    diff: list[str] = []
+    items1, items2 = ds1.get_items(), ds2.get_items()
+    if len(items1) != len(items2):
+        diff.append(f"Different number of items: {len(items1)} != {len(items2)}")
+    else:
+        for item1, item2 in zip(items1, items2):
+            name1, name2 = item1.get_name(), item2.get_name()
+            if item1 != item2:
+                diff.append(f"Item '{name1}' differs from '{name2}'")
+            val1, val2 = item1.get_value(ds1), item2.get_value(ds2)
+            diffval = False
+            if isinstance(val1, (list, tuple, set)):
+                if not all(v1 == v2 for v1, v2 in zip(val1, val2)):
+                    diffval = True
+            elif isinstance(val1, np.ndarray) and isinstance(val2, np.ndarray):
+                if not np.array_equal(val1, val2):
+                    diffval = True
+            elif val1 != val2:
+                diffval = True
+            if diffval:
+                diff.append(f"Item '{name1}' has different value: {val1} != {val2}")
+    if diff:
+        msg = "" if msg is None else msg + "\n"
+        raise AssertionError(msg + "Datasets are not equal:\n" + "\n".join(diff))
+
+
 class DataSet(metaclass=DataSetMeta):
     """Construct a DataSet object is a set of DataItem objects
 
@@ -1059,32 +1363,84 @@ class DataSet(metaclass=DataSetMeta):
         title (str): title
         comment (str): comment. Text shown on the top of the first data item
         icon (str): icon filename as in image search paths
+        readonly (bool): if True, the DataSet is read-only
+        skip_defaults (bool): if True, do not set default values for items
     """
 
     _items: list[DataItem] = []
     __metaclass__ = DataSetMeta  # keep it even with Python 3 (see DataSetMeta)
 
+    # Class-level configuration (set via __init_subclass__)
+    _class_title: str | None = None
+    _class_comment: str | None = None
+    _class_icon: str = ""
+    _class_readonly: bool = False
+
+    def __init_subclass__(
+        cls,
+        title: str | None = None,
+        comment: str | None = None,
+        icon: str = "",
+        readonly: bool = False,
+        **kwargs,
+    ) -> None:
+        """Called when a class inherits from DataSet.
+
+        This allows configuring DataSet metadata in the class definition:
+
+            class MyParams(DataSet, title="My Parameters", icon="myicon.png"):
+                param1 = FloatItem("Parameter 1")
+
+        Args:
+            title: Default title for this DataSet class
+            comment: Default comment for this DataSet class
+            icon: Default icon for this DataSet class
+            readonly: Default readonly state for this DataSet class
+            **kwargs: Additional arguments passed to parent __init_subclass__
+        """
+        super().__init_subclass__(**kwargs)
+        cls._class_title = title
+        cls._class_comment = comment
+        cls._class_icon = icon
+        cls._class_readonly = readonly
+
     def __init__(
         self,
         title: str | None = None,
         comment: str | None = None,
         icon: str = "",
         readonly: bool = False,
+        skip_defaults: bool = False,
     ):
-        self.__comment = comment
-        self.__icon = icon
-        comp_title, comp_comment = self._compute_title_and_comment()
-        if title:
+        # Priority: instance parameter > class-level config > empty/computed default
+        self.__icon = icon if icon else self._class_icon
+        self.__readonly: bool = readonly or self._class_readonly
+
+        # Handle title: instance param > class config > docstring fallback
+        if title is not None:
+            # Explicitly passed to __init__ (even if empty string)
             self.__title = title
+        elif self._class_title is not None:
+            # Set at class level via __init_subclass__ (even if empty string)
+            self.__title = self._class_title
         else:
+            # Fall back to docstring (for backward compatibility)
+            comp_title, comp_comment = self._compute_title_and_comment()
             self.__title = comp_title
-        if comment is None:
-            self.__comment = comp_comment
-        self.__changed = False
 
-        self.__readonly: bool = readonly
+        # Handle comment: instance param > class config > None (no docstring fallback)
+        if comment is not None:
+            # Explicitly passed to __init__
+            self.__comment = comment
+        elif self._class_comment is not None:
+            # Set at class level via __init_subclass__
+            self.__comment = self._class_comment
+        else:
+            # No automatic fallback to docstring for comment
+            self.__comment = None
 
-        self.set_defaults()
+        if not skip_defaults:
+            self.set_defaults()
 
     def get_items(self, copy=False) -> list[DataItem]:
         """Returns all the DataItem objects from the DataSet instance. Ignore private
@@ -1110,14 +1466,28 @@ class DataSet(metaclass=DataSetMeta):
         Returns:
             DataSet instance
         """  # noqa
-        instance = cls()
+        # Validate that all kwargs correspond to actual items in the class
         for name in kwargs:
-            for item in instance._items:
+            for item in cls._items:
                 if item._name == name:
-                    setattr(instance, name, kwargs[name])
                     break
             else:
-                raise AttributeError(f"Unknown attribute {name}")
+                raise AttributeError(
+                    f"DataSet class '{cls.__name__}' has no attribute '{name}'"
+                )
+
+        # Create the instance but skip set_defaults in __init__
+        instance = cls(skip_defaults=True)
+
+        # Set only the defaults for items that don't have values in kwargs
+        for item in instance._items:
+            if item._name not in kwargs:
+                item.set_default(instance)
+
+        # Now set the provided values
+        for name, value in kwargs.items():
+            setattr(instance, name, value)
+
         return instance
 
     def _get_translation(self):
@@ -1135,18 +1505,24 @@ class DataSet(metaclass=DataSetMeta):
 
     def _compute_title_and_comment(self) -> tuple[str, str | None]:
         """
-        Private method to compute title and comment of the data set
+        Private method to compute title and comment of the data set from docstring.
+
+        Returns tuple of (title, comment) where:
+        - title: first line of docstring (stripped), or class name if no docstring
+        - comment: remaining lines of docstring (stripped), or None if no lines
         """
         comp_title = self.__class__.__name__
         comp_comment = None
         if self.__doc__:
             doc_lines = self.__doc__.splitlines()
-            # Remove empty lines at the begining of comment
+            # Remove empty lines at the beginning
             while doc_lines and not doc_lines[0].strip():
                 del doc_lines[0]
             if doc_lines:
+                # First line becomes the title
                 comp_title = doc_lines.pop(0).strip()
             if doc_lines:
+                # Remaining lines become the comment
                 comp_comment = "\n".join([x.strip() for x in doc_lines])
         return comp_title, comp_comment
 
@@ -1158,6 +1534,14 @@ class DataSet(metaclass=DataSetMeta):
         """
         return self.__title
 
+    def set_title(self, title: str) -> None:
+        """Set data set title
+
+        Args:
+            title (str): title
+        """
+        self.__title = title
+
     def get_comment(self) -> str | None:
         """Return data set comment
 
@@ -1166,6 +1550,14 @@ class DataSet(metaclass=DataSetMeta):
         """
         return self.__comment
 
+    def set_comment(self, comment: str | None) -> None:
+        """Set data set comment
+
+        Args:
+            comment (str | None): comment
+        """
+        self.__comment = comment
+
     def get_icon(self) -> str | None:
         """Return data set icon
 
@@ -1174,12 +1566,21 @@ class DataSet(metaclass=DataSetMeta):
         """
         return self.__icon
 
+    def set_icon(self, icon: str) -> None:
+        """Set data set icon
+
+        Args:
+            icon (str): icon
+        """
+        self.__icon = icon
+
     def set_defaults(self) -> None:
         """Set default values"""
         for item in self._items:
             item.set_default(self)
 
-    def __str__(self):
+    def __str__(self) -> str:
+        """Return string representation of the data set"""
         return self.to_string(debug=False)
 
     def check(self) -> list[str]:
@@ -1206,7 +1607,8 @@ class DataSet(metaclass=DataSetMeta):
         apply: Callable | None = None,
         wordwrap: bool = True,
         size: QSize | tuple[int, int] | None = None,
-    ) -> DataSetEditDialog:
+        object_name: str | None = None,
+    ) -> int:
         """Open a dialog box to edit data set
 
         Args:
@@ -1214,6 +1616,11 @@ class DataSet(metaclass=DataSetMeta):
             apply: apply callback (default is None)
             wordwrap: if True, comment text is wordwrapped
             size: dialog size (QSize object or integer tuple (width, height))
+            object_name: object name for the dialog (default is None, meaning
+             use class name + "Dialog")
+
+        Returns:
+            Dialog exit code.
         """
         # Importing those modules here avoids Qt dependency when
         # guidata is used without Qt
@@ -1229,6 +1636,7 @@ class DataSet(metaclass=DataSetMeta):
             wordwrap=wordwrap,
             size=size,
         )
+        dlg.setObjectName(object_name or self.__class__.__name__ + "Dialog")
 
         return exec_dialog(dlg)
 
@@ -1262,6 +1670,17 @@ class DataSet(metaclass=DataSetMeta):
     def set_readonly(self, readonly: bool = True):
         self.__readonly = readonly
 
+    def _get_items_for_text_representation(self) -> list[DataItem]:
+        """Get items for text representation, excluding trailing separators
+
+        Returns:
+            list: List of items with trailing separators filtered out
+        """
+        filtered_items = list(self._items)
+        while filtered_items and isinstance(filtered_items[-1], SeparatorItem):
+            filtered_items.pop()
+        return filtered_items
+
     def to_string(
         self,
         debug: bool | None = False,
@@ -1293,13 +1712,16 @@ class DataSet(metaclass=DataSetMeta):
             else:
                 return item.get_prop_value("display", self, "label")
 
+        # Get items for text representation (excluding trailing separators)
+        filtered_items = self._get_items_for_text_representation()
+
         length = 0
         if align:
-            for item in self._items:
+            for item in filtered_items:
                 item_length = len(_get_label(item))
                 if item_length > length:
                     length = item_length
-        for item in self._items:
+        for item in filtered_items:
             try:
                 hide = item.get_prop_value("display", self, "hide")
                 if not show_hidden and hide is True:
@@ -1325,6 +1747,9 @@ class DataSet(metaclass=DataSetMeta):
                 label = item._name
             else:
                 label = item.get_prop_value("display", self, "label")
+                if not label:
+                    # For BoolItem without label, use text as label
+                    label = item.get_prop_value("display", self, "text", "")
             if length and label is not None:
                 label = label.ljust(length)
             txt += f"{indent}{label}: {value_str}"
@@ -1342,6 +1767,85 @@ class DataSet(metaclass=DataSetMeta):
         for item in self._items:
             item.accept(vis)
 
+    def to_html(self) -> str:
+        """Return HTML representation of the dataset.
+
+        Similar to Sigima's TableResult transpose format with:
+
+        - Title and comment in blue
+        - Two-column table: item names (right-aligned) and values (left-aligned)
+        - For BoolItem: checkbox in first column with label:text formatting
+
+        Returns:
+            HTML representation
+        """
+        # Create the title with comment
+        # Use a lighter blue (#5294e2) that works well in both light and dark modes
+        html = f'<u><b style="color: #5294e2">{self.__title}</b></u>:'
+
+        if self.__comment:
+            # Add comment on new line, also in blue
+            html += f'<br><span style="color: #5294e2">{self.__comment}</span>'
+
+        # Get items for representation (excluding trailing separators)
+        filtered_items = self._get_items_for_text_representation()
+
+        if not filtered_items:
+            html += "<br><em>No items to display</em>"
+            return html
+
+        # Start table
+        html += '<table border="0">'
+
+        for item in filtered_items:
+            # Skip group items and separators for HTML representation
+            if isinstance(item, (BeginGroup, EndGroup, SeparatorItem)):
+                continue
+
+            # Skip hidden items
+            try:
+                hide = item.get_prop_value("display", self, "hide")
+                if hide is True:
+                    continue
+            except KeyError:
+                pass
+
+            # Handle ObjectItem (nested datasets)
+            if isinstance(item, ObjectItem):
+                composite_dataset = item.get_value(self)
+                if hasattr(composite_dataset, "to_html"):
+                    item_label = item.get_prop_value("display", self, "label")
+                    html += (
+                        f'<tr><td style="text-align: right; vertical-align: top;">'
+                        f"{item_label}:</td>"
+                    )
+                    nested_html = composite_dataset.to_html(transpose=False)
+                    html += (
+                        f'<td style="text-align: left; padding-left: 10px;">'
+                        f"{nested_html}</td></tr>"
+                    )
+                continue
+
+            # Get item label and value
+            label = item.get_prop_value("display", self, "label")
+            if not label:
+                # For BoolItem without label, use name:text formatting
+                label = item.get_prop_value("display", self, "text", "")
+
+            # Get string representation of value
+            value_str = item.get_string_value(self)
+
+            html += (
+                f'<tr><td style="text-align: right; vertical-align: top;">{label}:</td>'
+            )
+            html += (
+                f'<td style="text-align: left; padding-left: 10px;">'
+                f"{value_str}</td></tr>"
+            )
+
+        html += "</table>"
+        return html
+
     def serialize(self, writer: HDF5Writer | JSONWriter | INIWriter) -> None:
         """Serialize the dataset
 
@@ -1360,6 +1864,8 @@ class DataSet(metaclass=DataSetMeta):
         """
         for item in self._items:
             with reader.group(item._name):
+                if item.get_prop("data", "computed", None) is not None:
+                    continue  # Skip computed items
                 try:
                     item.deserialize(self, reader)
                 except RuntimeError as error:
@@ -1679,3 +2185,105 @@ class EndTabGroup(EndGroup):
     """
 
     pass
+
+
+class SeparatorItem(DataItem):
+    """Data item which represents a visual separator between other items
+
+    In textual representation, it appears as a series of dashes.
+    In GUI, it appears as a horizontal gray line.
+
+    Args:
+        label (str): optional label for the separator (default: "")
+    """
+
+    def __init__(self, label: str = "") -> None:
+        super().__init__(label)
+
+    def get_string_value(self, instance: DataSet) -> str:
+        """Return a formatted string representation of the separator
+
+        Args:
+            instance (DataSet): instance of the DataSet
+
+        Returns:
+            str: string representation as a series of dashes
+        """
+        return "-" * 50  # Return a line of 50 dashes
+
+    def serialize(
+        self, instance: DataSet, writer: HDF5Writer | JSONWriter | INIWriter
+    ) -> None:
+        """Serialize this item using the writer object
+
+        Separators don't store any data, so this is a no-op.
+
+        Args:
+            instance (DataSet): instance of the DataSet
+            writer (HDF5Writer | JSONWriter | INIWriter): writer object
+        """
+        pass
+
+    def deserialize(
+        self, instance: DataSet, reader: HDF5Reader | JSONReader | INIReader
+    ) -> None:
+        """Deserialize this item using the reader object
+
+        Separators don't store any data, so this is a no-op.
+
+        Args:
+            instance (DataSet): instance of the DataSet
+            reader (HDF5Reader | JSONReader | INIReader): reader object
+        """
+        pass
+
+    def check_value(self, value: Any, raise_exception: bool = False) -> bool:
+        """Check if `value` is valid for this data item
+
+        Separators don't store values, so always return True.
+
+        Args:
+            value (Any): value to check
+            raise_exception (bool): if True, raise an exception if the value is invalid
+
+        Returns:
+            bool: True (separators always have valid "values")
+        """
+        return True
+
+    def from_string(self, string_value: str) -> None:
+        """Transform string into valid data item's value
+
+        Separators don't store values, so return None.
+
+        Args:
+            string_value (str): string value
+
+        Returns:
+            None: separators don't have values
+        """
+        return None
+
+    def get_value(self, instance: DataSet) -> None:
+        """Return data item's value
+
+        Separators don't store values.
+
+        Args:
+            instance (DataSet): instance of the DataSet
+
+        Returns:
+            None: separators don't have values
+        """
+        return None
+
+    def __set__(self, instance: DataSet, value: Any) -> None:
+        """Set data item's value
+
+        Separators don't store values, so this is a no-op.
+
+        Args:
+            instance (DataSet): instance of the DataSet
+            value (Any): value to set (ignored)
+        """
+        pass  # Separators don't store any value
