@@ -90,6 +90,7 @@ from guidata.dataset.datatypes import (
     DataSetGroup,
     EndGroup,
     GroupItem,
+    SeparatorItem,
     TabGroupItem,
 )
 from guidata.qthelpers import win32_fix_title_bar_background
@@ -126,6 +127,7 @@ class DataSetEditDialog(QDialog):
         self._layout = QVBoxLayout()
         if instance.get_comment():
             label = QLabel(instance.get_comment())
+            label.setTextInteractionFlags(Qt.TextSelectableByMouse)
             label.setWordWrap(wordwrap)
             self._layout.addWidget(label)
         self.instance = instance
@@ -264,7 +266,6 @@ class DataSetGroupEditDialog(DataSetEditDialog):
         Args:
             instance: DataSetGroup instance to edit
         """
-
         assert isinstance(instance, DataSetGroup)
         tabs = QTabWidget()
         #        tabs.setUsesScrollButtons(False)
@@ -275,6 +276,7 @@ class DataSetGroupEditDialog(DataSetEditDialog):
             layout.setAlignment(Qt.AlignmentFlag.AlignTop)
             if dataset.get_comment():
                 label = QLabel(dataset.get_comment())
+                label.setTextInteractionFlags(Qt.TextSelectableByMouse)
                 label.setWordWrap(self.wordwrap)
                 layout.addWidget(label)
             grid = QGridLayout()
@@ -298,6 +300,7 @@ class DataSetEditLayout(Generic[AnyDataSet]):
         items: list of data items
         first_line: first line of grid layout
         change_callback: function called when any widget's value has changed
+        group_widget: group widget associated with this layout, if any
     """
 
     _widget_factory: dict[Any, Any] = {}
@@ -320,17 +323,22 @@ class DataSetEditLayout(Generic[AnyDataSet]):
         items: list[DataItem] | None = None,
         first_line: int = 0,
         change_callback: Callable | None = None,
+        group_widget: GroupWidget | None = None,
     ) -> None:
         self.parent = parent
         self.instance = instance
         self.layout = layout
         self.first_line = first_line
         self.change_callback = change_callback
+        self.group_widget = group_widget
         self.widgets: list[AbstractDataSetWidget] = []
         # self.linenos = {}  # prochaine ligne à remplir par colonne
         self.items_pos: dict[DataItem, list[int]] = {}
         if not items:
             items = self.instance._items
+        # Filter out trailing separators for GUI display
+        while items and isinstance(items[-1], SeparatorItem):
+            items = items[:-1]
         items = self.transform_items(items)  # type:ignore
         self.setup_layout(items)
 
@@ -501,6 +509,24 @@ class DataSetEditLayout(Generic[AnyDataSet]):
         if self.change_callback is not None:
             self.change_callback()
 
+    def get_terminal_widgets(self) -> list[AbstractDataSetWidget]:
+        """Get all terminal widgets (i.e. not GroupWidget or TabGroupWidget).
+
+        Returns:
+            List of terminal widgets
+        """
+        stack = self.widgets[:]
+        terminal_widgets = []
+        while stack:
+            widget = stack.pop()
+            if isinstance(widget, GroupWidget):
+                stack.extend(widget.edit.widgets)
+            elif isinstance(widget, TabGroupWidget):
+                stack.extend(widget.widgets)
+            else:
+                terminal_widgets.append(widget)
+        return terminal_widgets
+
 
 from guidata.dataset.dataitems import (  # noqa: E402
     BoolItem,
@@ -539,6 +565,7 @@ from guidata.dataset.qtitemwidgets import (  # noqa: E402
     GroupWidget,
     LineEditWidget,
     MultipleChoiceWidget,
+    SeparatorWidget,
     SliderWidget,
     TabGroupWidget,
     TextEditWidget,
@@ -571,6 +598,7 @@ DataSetEditLayout.register(MultipleChoiceItem, MultipleChoiceWidget)
 DataSetEditLayout.register(FloatArrayItem, FloatArrayWidget)
 DataSetEditLayout.register(ButtonItem, ButtonWidget)
 DataSetEditLayout.register(DictItem, ButtonWidget)
+DataSetEditLayout.register(SeparatorItem, SeparatorWidget)
 
 
 LABEL_CSS = """
@@ -746,6 +774,7 @@ DataSetShowLayout.register(ImageChoiceItem, DataSetShowWidget)
 DataSetShowLayout.register(MultipleChoiceItem, DataSetShowWidget)
 DataSetShowLayout.register(FloatArrayItem, DataSetShowWidget)
 DataSetShowLayout.register(DictItem, DataSetShowWidget)
+DataSetShowLayout.register(SeparatorItem, SeparatorWidget)
 
 
 class DataSetShowGroupBox(Generic[AnyDataSet], QGroupBox):
@@ -772,6 +801,7 @@ class DataSetShowGroupBox(Generic[AnyDataSet], QGroupBox):
         self._layout = QVBoxLayout()
         if self.dataset.get_comment():
             label = QLabel(self.dataset.get_comment())
+            label.setTextInteractionFlags(Qt.TextSelectableByMouse)
             label.setWordWrap(wordwrap)
             self._layout.addWidget(label)
         self.grid_layout = QGridLayout()
@@ -789,11 +819,23 @@ class DataSetShowGroupBox(Generic[AnyDataSet], QGroupBox):
 
     def get(self) -> None:
         """Update group box contents from data item values"""
-        for widget in self.edit.widgets:
+        # Set build_mode=True for ALL widgets (including nested ones) FIRST
+        # to prevent update_dataitems() from being called during callbacks
+        # (which would write stale widget values back to the dataset before
+        # those widgets have been updated)
+        all_widgets = self.edit.get_terminal_widgets()
+        for widget in all_widgets:
             widget.build_mode = True
+
+        # Now update all widgets from dataset
+        for widget in self.edit.widgets:
             widget.get()
             widget.set_state()
+
+        # Reset build_mode after all updates are complete
+        for widget in all_widgets:
             widget.build_mode = False
+
         if self.apply_button is not None:
             self.apply_button.setVisible(not self.dataset.is_readonly())
 
@@ -846,6 +888,7 @@ class DataSetEditGroupBox(DataSetShowGroupBox[AnyDataSet]):
                 -1,
                 Qt.AlignRight,  # type:ignore
             )
+            layout.setRowStretch(layout.rowCount() + 1, 1)
 
     def get_edit_layout(self) -> DataSetEditLayout[AnyDataSet]:
         """Return edit layout
@@ -1067,6 +1110,7 @@ class DataSetGroupTableEditDialog(QDialog):
         self._layout = QVBoxLayout()
         if instance.get_comment():
             label = QLabel(instance.get_comment())
+            label.setTextInteractionFlags(Qt.TextSelectableByMouse)
             label.setWordWrap(wordwrap)
             self._layout.addWidget(label)
         self.instance = instance
