@@ -44,8 +44,6 @@ Other
 
 .. autofunction:: grab_save_window
 
-.. autofunction:: click_on_widget
-
 .. autofunction:: block_signals
 
 .. autofunction:: qt_wait
@@ -70,7 +68,7 @@ from qtpy import QtWidgets as QW
 
 import guidata
 from guidata.config import _
-from guidata.configtools import get_icon, get_module_data_path
+from guidata.configtools import get_icon
 from guidata.env import execenv
 from guidata.external import darkdetect
 
@@ -100,11 +98,11 @@ def set_dark_mode(state: bool) -> None:
 
 
 def is_dark_mode() -> bool:
-    """Return True if current color mode is dark mode
+    """Return True if current color theme is dark
     (deprecated, use `is_dark_theme` instead)
 
     Returns:
-        True if dark mode is enabled
+        True if dark theme is enabled
     """
     warnings.warn(
         "`is_dark_mode` is deprecated and will be removed in a future version. "
@@ -125,6 +123,11 @@ def get_color_theme() -> Literal["light", "dark"]:
         Color theme ('light' or 'dark')
     """
     global CURRENT_THEME
+
+    # Return cached theme if available
+    if CURRENT_THEME is not None:
+        return CURRENT_THEME
+
     mode = get_color_mode()
     if mode == AUTO:
         theme = DARK if darkdetect.isDark() else LIGHT
@@ -135,20 +138,16 @@ def get_color_theme() -> Literal["light", "dark"]:
 
 
 def is_dark_theme() -> bool:
-    """Return True if current color mode is dark mode.
-
-    Color theme value is updated only once per session because the query to the system
-    may be expensive depending on the platform. It is updated when the color mode is
-    set to 'auto' using `set_color_mode('auto')`.
+    """Return True if current color theme is dark.
 
     Returns:
-        True if dark mode is enabled
+        True if dark theme is enabled
     """
     return get_color_theme() == DARK
 
 
 def get_color_mode() -> Literal["light", "dark", "auto"]:
-    """Get color mode
+    """Get color mode setting.
 
     Returns:
         Color mode ('light', 'dark' or 'auto')
@@ -720,6 +719,10 @@ def exec_dialog(dlg: QW.QDialog) -> int:
         int: Dialog exit code
     """
     if execenv.unattended:
+        # Important: process all pending Qt events before scheduling dialog closure.
+        # This avoids side-effects between tests (timers, widgets) and ensures
+        # clean dialog lifecycle in non-interactive automated test environments.
+        QW.QApplication.processEvents()
         QC.QTimer.singleShot(
             execenv.delay,
             lambda: close_dialog_and_quit(dlg, screenshot=execenv.screenshot),
@@ -731,42 +734,38 @@ def exec_dialog(dlg: QW.QDialog) -> int:
     return result
 
 
-def grab_save_window(widget: QW.QWidget, name: str) -> None:  # pragma: no cover
+def grab_save_window(
+    widget: QW.QWidget,
+    name: str | None = None,
+    save_dir: str | None = None,
+    add_timestamp: bool = False,
+) -> None:  # pragma: no cover
     """Grab window screenshot and save it
 
     Args:
-        widget (QWidget): Widget to grab
-        name (str): Widget name
+        widget: Widget to grab
+        name: Widget name. If None, uses ``widget.objectName()``
+        save_dir: Directory to save screenshot. If None, uses
+         ``execenv.screenshot_path`` or current working directory
+        add_timestamp: Whether to add timestamp suffix to filename
     """
+    if name is None:
+        name = widget.objectName()
+
     widget.activateWindow()
     widget.raise_()
     QW.QApplication.processEvents()
     pixmap = widget.grab()
+
     suffix = ""
-    if not name[-1].isdigit() and not name.startswith(("s_", "i_")):
+    if add_timestamp:
         suffix = "_" + datetime.now().strftime("%Y-%m-%d-%H%M%S")
-    pixmap.save(
-        osp.join(
-            get_module_data_path("guidata"),
-            os.pardir,
-            "doc",
-            "images",
-            "shots",
-            f"{name}{suffix}.png",
-        )
-    )
 
+    if save_dir is None:
+        save_dir = execenv.screenshot_path or os.getcwd()
+    os.makedirs(save_dir, exist_ok=True)
 
-def click_on_widget(widget: QW.QWidget) -> None:
-    """Click on widget and eventually save a screenshot
-
-    Args:
-        widget (QWidget): Widget to click on
-    """
-    wname = widget.objectName()
-    if wname and widget.isVisible():  # pragma: no cover
-        grab_save_window(widget, wname.lower())
-    widget.clicked()
+    pixmap.save(osp.join(save_dir, f"{name}{suffix}.png"))
 
 
 @contextmanager
@@ -839,6 +838,23 @@ def qt_wait(
         msgbox.deleteLater()
 
 
+def qt_wait_until(
+    condition: Callable[[], bool], timeout: float = 5.0, interval: float = 0.05
+) -> None:
+    """Wait until a condition is met or timeout occurs, processing Qt events.
+
+    Args:
+        condition: A callable that returns True when the condition is met.
+        timeout: Maximum time to wait in seconds.
+        interval: Time to wait between checks in seconds.
+    """
+    end = time.time() + timeout
+    while not condition() and time.time() < end:
+        QW.QApplication.processEvents()
+        time.sleep(interval)
+    assert condition(), "Condition not met within timeout"
+
+
 @contextmanager
 def save_restore_stds() -> Generator[None, None, None]:
     """Save/restore standard I/O before/after doing some things
