@@ -21,9 +21,9 @@ import re
 import requests
 
 try:
-    import tomllib  # Python 3.11+
+    import tomllib  # type: ignore # Python 3.11+
 except ImportError:
-    import tomli as tomllib  # fallback pour Python <3.11
+    import tomli as tomllib  # fallback for Python <3.11
 
 
 def __parse_toml_requirements(pyproject_fname: str) -> dict[str, list[str]] | None:
@@ -96,8 +96,18 @@ def __convert_requirements_to_rst_table(reqs: list[str]) -> str:
     modlist = []
     for req in reqs:
         try:
-            mod = re.split(" ?(>=|<=|=|<|>)", req)[0]
-            ver = req[len(mod) :]
+            # Split by environment marker first (semicolon)
+            req_parts = req.split(";", 1)
+            req_main = req_parts[0].strip()
+            env_marker = req_parts[1].strip() if len(req_parts) > 1 else ""
+
+            # Now split the main requirement by version operators
+            mod = re.split(" ?(>=|<=|=|<|>)", req_main)[0]
+            ver = req_main[len(mod) :].strip()
+
+            # Add environment marker to version if present
+            if env_marker:
+                ver = f"{ver} ({env_marker})" if ver else f"({env_marker})"
         except ValueError:
             mod, ver = req, ""
         if mod.lower() in modlist:
@@ -161,42 +171,9 @@ def __extract_exact_requirements(dependencies: list[str]) -> list[str]:
     return list(dependencies)
 
 
-def __extract_min_requirements(dependencies: list[str]) -> list[str]:
-    """Convert 'pkg>=x.y.z' into 'pkg==x.y.z', ignoring complex constraints.
-
-    Args:
-        dependencies: List of dependency strings from pyproject.toml.
-
-    Returns:
-        List of minimal requirements with version pinned to the minimum specified.
-        Complex constraints (e.g., with <, >, ~, !, *, ;) are skipped with a warning.
-    """
-    result = []
-    for dep in dependencies:
-        if any(op in dep for op in ("<", ">", "~", "!", "*", ";", "==")):
-            parts = dep.split(">=")
-            if len(parts) == 2 and not any(
-                op in parts[1] for op in ("<", "~", "!", "*", ";")
-            ):
-                result.append(f"{parts[0].strip()}=={parts[1].strip()}")
-            else:
-                parts = dep.split(">")
-                if len(parts) == 2:
-                    print(
-                        f"ℹ️  Removing version constraint for strict requirement: {dep}"
-                    )
-                    result.append(parts[0].strip())
-                else:
-                    print(f"⚠️  Skipping complex requirement: {dep}")
-        else:
-            result.append(dep)  # No version specified
-    return result
-
-
 def generate_requirements_txt(
     pyproject_fname: str,
     output_fname: str,
-    minimal: bool = False,
     include_optional: bool = False,
 ) -> None:
     """Process the pyproject.toml file and write requirements to output file.
@@ -204,7 +181,6 @@ def generate_requirements_txt(
     Args:
         pyproject_path: Path to the pyproject.toml file.
         output_path: Path to the output requirements file.
-        minimal: If True, generate minimal requirements (pkg==x.y.z).
         include_optional: If True, include optional dependencies.
     """
     pyproject_path = pathlib.Path(pyproject_fname)
@@ -218,13 +194,12 @@ def generate_requirements_txt(
     project = data.get("project", {})
     deps = project.get("dependencies", [])
 
-    extract_fn = __extract_min_requirements if minimal else __extract_exact_requirements
-    all_deps = extract_fn(deps)
+    all_deps = __extract_exact_requirements(deps)
 
     if include_optional:
         opt_deps = project.get("optional-dependencies", {})
         for extra, deps in opt_deps.items():
-            all_deps += extract_fn(deps)
+            all_deps += __extract_exact_requirements(deps)
 
     # Remove duplicates and sort
     all_deps = sorted(set(all_deps))
@@ -241,14 +216,12 @@ def main() -> None:
     parser = argparse.ArgumentParser(
         description="Convert pyproject.toml to documentation or requirements files",
         epilog="Use 'rst' to generate requirements.rst, "
-        "'txt' for requirements.txt or requirements-min.txt, "
+        "'txt' for requirements.txt, "
         "'all' for both formats.",
     )
     subparsers = parser.add_subparsers(dest="command", required=True)
 
-    txt_parser = subparsers.add_parser(
-        "txt", help="Generate requirements.txt or requirements-min.txt"
-    )
+    txt_parser = subparsers.add_parser("txt", help="Generate requirements.txt")
     txt_parser.add_argument(
         "--pyproject",
         default="pyproject.toml",
@@ -257,12 +230,7 @@ def main() -> None:
     txt_parser.add_argument(
         "--output",
         default=None,
-        help="Output filename (default: requirements.txt or requirements-min.txt)",
-    )
-    txt_parser.add_argument(
-        "--min",
-        action="store_true",
-        help="Generate requirements-min.txt with minimal versions (pkg==x.y.z)",
+        help="Output filename (default: requirements.txt)",
     )
     txt_parser.add_argument(
         "--include-optional",
@@ -290,11 +258,10 @@ def main() -> None:
     args = parser.parse_args()
 
     if args.command == "txt":
-        default_output = "requirements-min.txt" if args.min else "requirements.txt"
+        default_output = "requirements.txt"
         generate_requirements_txt(
             pyproject_fname=osp.abspath(args.pyproject),
             output_fname=osp.abspath(args.output or default_output),
-            minimal=args.min,
             include_optional=args.include_optional,
         )
     elif args.command == "rst":
@@ -307,13 +274,6 @@ def main() -> None:
         generate_requirements_txt(
             pyproject_fname=osp.abspath("pyproject.toml"),
             output_fname=osp.abspath("requirements.txt"),
-            minimal=False,
-            include_optional=True,
-        )
-        generate_requirements_txt(
-            pyproject_fname=osp.abspath("pyproject.toml"),
-            output_fname=osp.abspath("requirements-min.txt"),
-            minimal=True,
             include_optional=True,
         )
         generate_requirements_rst(
