@@ -11,7 +11,6 @@
 # pylint: disable=R0911
 # pylint: disable=R0201
 
-
 import builtins
 import keyword
 import locale
@@ -77,7 +76,7 @@ class ShellBaseWidget(ConsoleBaseWidget, SaveHistoryMixin, BrowseHistoryMixin):
 
     def __init__(self, parent, profile=False, initial_message=None, read_only=False):
         """
-        parent : specifies the parent widget
+        `parent` : specifies the parent widget
         """
         ConsoleBaseWidget.__init__(self, parent)
         SaveHistoryMixin.__init__(self)
@@ -161,8 +160,7 @@ class ShellBaseWidget(ConsoleBaseWidget, SaveHistoryMixin, BrowseHistoryMixin):
             _("Save history log..."),
             icon=get_icon("filesave.png"),
             tip=_(
-                "Save current history log (i.e. all "
-                "inputs and outputs) in a text file"
+                "Save current history log (i.e. all inputs and outputs) in a text file"
             ),
             triggered=self.save_historylog,
         )
@@ -730,7 +728,7 @@ class PythonShellWidget(TracebackLinksMixin, ShellBaseWidget, GetHelpMixin):
                 self,
                 _("Clear shell"),
                 icon=get_icon("editclear.png"),
-                tip=_("Clear shell contents " "('cls' command)"),
+                tip=_("Clear shell contents ('cls' command)"),
                 triggered=self.clear_terminal,
             )
             actions += [clear_line_action, clear_action]
