@@ -8,6 +8,8 @@
 # (BSD 3-clause; see NOTICE.txt in the Spyder root directory for details).
 # -----------------------------------------------------------------------------
 
+# ruff: noqa
+
 """
 guidata.widgets.dataframeeditor
 ===============================
@@ -27,6 +29,7 @@ The current version is qtpandas/models/DataFrameModel.py of the
 """
 
 import io
+from qtpy.compat import getsavefilename
 
 import numpy as np
 from pandas import DataFrame, DatetimeIndex, Series
@@ -114,9 +117,10 @@ class DataFrameModel(QAbstractTableModel):
     ROWS_TO_LOAD = 500
     COLS_TO_LOAD = 40
 
-    def __init__(self, dataFrame, format=DEFAULT_FORMAT, parent=None):
+    def __init__(self, dataFrame, format=DEFAULT_FORMAT, parent=None, readonly=False):
         QAbstractTableModel.__init__(self)
         self.dialog = parent
+        self.readonly = readonly
         self.df = dataFrame
         self.df_index = dataFrame.index.tolist()
         self.df_header = dataFrame.columns.tolist()
@@ -391,7 +395,7 @@ class DataFrameModel(QAbstractTableModel):
         column = index.column()
         row = index.row()
 
-        if index in self.display_error_idxs:
+        if index in self.display_error_idxs or self.readonly:
             return False
         if change_type is not None:
             try:
@@ -608,7 +612,7 @@ class DataFrameView(QTableView):
         ) + self.frozen_table_view.columnWidth(1)
         topleft_x = self.visualRect(current).topLeft().x()
 
-        overflow = self.MoveLeft and current.column() > 1
+        overflow = cursor_action == QAbstractItemView.MoveLeft and current.column() > 1
         overflow = overflow and topleft_x < col_width
 
         if cursor_action == overflow:
@@ -667,22 +671,23 @@ class DataFrameView(QTableView):
             triggered=self.copy,
             context=Qt.WidgetShortcut,
         )
-        functions = (
-            (_("To bool"), bool),
-            (_("To complex"), complex),
-            (_("To int"), int),
-            (_("To float"), float),
-            (_("To str"), str),
-        )
-        types_in_menu = [copy_action]
-        for name, func in functions:
-            # QAction.triggered works differently for PySide and PyQt
-            slot = lambda _checked, func=func: self.change_type(func)
-            types_in_menu += [
-                create_action(self, name, triggered=slot, context=Qt.WidgetShortcut)
-            ]
+        actions = [copy_action]
+        if not self.model().readonly:
+            functions = (
+                (_("To bool"), bool),
+                (_("To complex"), complex),
+                (_("To int"), int),
+                (_("To float"), float),
+                (_("To str"), str),
+            )
+            for name, func in functions:
+                # QAction.triggered works differently for PySide and PyQt
+                slot = lambda _checked, func=func: self.change_type(func)
+                actions += [
+                    create_action(self, name, triggered=slot, context=Qt.WidgetShortcut)
+                ]
         menu = QMenu(self)
-        add_actions(menu, types_in_menu)
+        add_actions(menu, actions)
         return menu
 
     def change_type(self, func):
@@ -741,19 +746,28 @@ class DataFrameEditor(QDialog):
         self.is_series = False
         self.layout = None
 
-    def setup_and_check(self, data, title=""):
-        """
-        Setup DataFrameEditor:
-        return False if data is not supported, True otherwise.
-        Supported types for data are DataFrame, Series and DatetimeIndex.
+    def setup_and_check(self, data, title="", readonly=False, add_title_suffix=True):
+        """Setup DataFrameEditor.
+
+        Args:
+            data: The DataFrame or Series to edit.
+            title: The dialog title.
+            readonly: If True, the DataFrame is not editable.
+            add_title_suffix: If True, the data type is added to the title.
+
+        Returns:
+            True if the editor could be set up, False otherwise.
         """
         self.layout = QGridLayout()
         self.setLayout(self.layout)
         self.setWindowIcon(get_icon("arredit.png"))
-        if title:
-            title = str(title) + " - %s" % data.__class__.__name__
-        else:
-            title = _("%s editor") % data.__class__.__name__
+        if add_title_suffix:
+            if title:
+                title = str(title) + " - %s" % data.__class__.__name__
+            else:
+                title = _("%s editor") % data.__class__.__name__
+            if readonly:
+                title += " (" + _("read only") + ")"
         if isinstance(data, Series):
             self.is_series = True
             data = data.to_frame()
@@ -763,7 +777,7 @@ class DataFrameEditor(QDialog):
         self.setWindowTitle(title)
         self.resize(600, 500)
 
-        self.dataModel = DataFrameModel(data, parent=self)
+        self.dataModel = DataFrameModel(data, parent=self, readonly=readonly)
         self.dataModel.dataChanged.connect(self.save_and_close_enable)
         self.dataTable = DataFrameView(self, self.dataModel)
 
@@ -772,13 +786,14 @@ class DataFrameEditor(QDialog):
         self.setMinimumSize(400, 300)
         # Make the dialog act as a window
         self.setWindowFlags(Qt.Window)
+
         btn_layout = QHBoxLayout()
 
-        btn = QPushButton(_("Format"))
+        btn = QPushButton(get_icon("format.svg"), _("Format"), self)
         # disable format button for int type
         btn_layout.addWidget(btn)
         btn.clicked.connect(self.change_format)
-        btn = QPushButton(_("Resize"))
+        btn = QPushButton(get_icon("resize.svg"), _("Resize"), self)
         btn_layout.addWidget(btn)
         btn.clicked.connect(self.resize_to_contents)
 
@@ -796,12 +811,23 @@ class DataFrameEditor(QDialog):
         self.bgcolor_global.stateChanged.connect(self.dataModel.colum_avg)
         btn_layout.addWidget(self.bgcolor_global)
 
+        btn_layout.addStretch(1)
+        btn = QPushButton(get_icon("copy_all.svg"), _("Copy all"), self)
+        btn.setToolTip(_("Copy all array data to clipboard"))
+        btn.clicked.connect(self.copy_all_to_clipboard)
+        btn_layout.addWidget(btn)
+        btn = QPushButton(get_icon("export.svg"), _("Export"), self)
+        btn.setToolTip(_("Export array to a file"))
+        btn_layout.addWidget(btn)
+        btn.clicked.connect(self.export_dataframe)
+
         btn_layout.addStretch()
 
-        self.btn_save_and_close = QPushButton(_("Save and Close"))
-        self.btn_save_and_close.setDisabled(True)
-        self.btn_save_and_close.clicked.connect(self.accept)
-        btn_layout.addWidget(self.btn_save_and_close)
+        if not readonly:
+            self.btn_save_and_close = QPushButton(_("Save and Close"))
+            self.btn_save_and_close.setDisabled(True)
+            self.btn_save_and_close.clicked.connect(self.accept)
+            btn_layout.addWidget(self.btn_save_and_close)
 
         self.btn_close = QPushButton(_("Close"))
         self.btn_close.setAutoDefault(True)
@@ -811,6 +837,9 @@ class DataFrameEditor(QDialog):
 
         self.layout.addLayout(btn_layout, 2, 0)
 
+        # Resize column 0 (index column) to contents
+        self.dataTable.resizeColumnToContents(0)
+
         return True
 
     @Slot(QModelIndex, QModelIndex)
@@ -856,6 +885,32 @@ class DataFrameEditor(QDialog):
             self.dataModel.set_format(format)
             self.sig_option_changed.emit("dataframe_format", format)
 
+    def copy_all_to_clipboard(self) -> None:
+        """Copy all array data, including headers, to clipboard"""
+        dataframe = self.dataModel.get_data()
+
+        if self.is_series:
+            dataframe = dataframe.iloc[:, 0]
+
+        output = io.StringIO()
+        dataframe.to_csv(output, sep="\t", index=True, header=True)
+        cliptxt = output.getvalue()
+        output.close()
+
+        if cliptxt:
+            clipboard = QApplication.clipboard()
+            clipboard.setText(cliptxt)
+
+    def export_dataframe(self) -> None:
+        """Export the dataframe to a CSV file with UTF-8 BOM."""
+        filename, _selfilter = getsavefilename(
+            self, _("Export dataframe"), "", _("CSV Files") + " (*.csv)"
+        )
+        if not filename:
+            return
+        dataframe = self.dataModel.get_data()
+        dataframe.to_csv(filename, sep="\t", index=True, header=True)
+
     def get_value(self):
         """Return modified Dataframe -- this is *not* a copy"""
         # It is import to avoid accessing Qt C++ object as it has probably
